# LaTexShortcuts

LaTex Shortcut is adds a couple of shortcuts that you can memorize to speed up your writing LaTex.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install LaTexShortcuts.

```bash
pip install LaTexShortcuts
```

## Usage

```python LaTexShortcuts.py```

```python3 LaTexShortcuts.py```

```python
import LaTexShortcuts
LaTexShortcuts.run()
```

Enjoy

## Shortcuts list

```Ctrl+Alt+F for fractions```

```Ctrl+Alt+I for integrals```

```Ctrl+Alt+D for d/dx```

```Ctrl+Alt+G for {} (used when writing in LaTex)```

```Ctrl+Alt+L for limits as x approaches ...```

```Ctrl+Alt+A for the infinity sign```

```Ctrl+Alt+S for blank space```



## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)